# Author:Patan Musthakheem Khan
# Version:0.1
# Licence:Apache 2.0
class Colors:
    def __init__(self):
        pass
    
    # THESE ARE THE CODES FOR COLORS IN LINUX TERMINAL JUST LIKE HTML
    # BG = BACKGROUND
    # BR = BRIGHT
    # BG_BR = BRIGHT BACKGROUND
    # THIS ONLY WORKS IN LINUX TERMINAL AND DIDN'T WORK IN CMD OR POWERSHELL IN WINDOWS
    RED = "\033[1;31m"
    BLUE = "\033[1;34m"
    CYAN = "\033[1;36m"
    YELLOW = "\u001b[33m"
    GREEN = "\033[0;32m"
    MAGENTA = "\u001b[35m"
    WHITE = "\u001b[37m"
    BLACK =  "\u001b[30m"
    BR_BLACK = "\u001b[30;1m"
    BR_RED = "\u001b[31;1m"
    BR_GREEN = "\u001b[32;1m"
    BR_YELLOW = "\u001b[33;1m"
    BR_BLUE = "\u001b[34;1m"
    BR_MAGENTA = "\u001b[35;1m"
    BR_CYAN = "\u001b[36;1m"
    BR_WHITE = "\u001b[37;1m"
    BG_BLACK = "\u001b[40m"
    BG_RED = "\u001b[41m"
    BG_GREEN = "\u001b[42m"
    BG_YELLOW = "\u001b[43m"
    BG_BLUE = "\u001b[44m"
    BG_MAGENTA = "\u001b[45m"
    BG_CYAN = "\u001b[46m"
    BG_WHITE = "\u001b[47m"
    BG_BR_BLACK = "\u001b[40;1m"
    BG_BR_RED = "\u001b[41;1m"
    BG_BR_GREEN = "\u001b[42;1m"
    BG_BR_YELLOW = "\u001b[43;1m"
    BG_BR_BLUE = "\u001b[44;1m"
    BG_BR_MAGENTA = "\u001b[45;1m"
    BG_BR_CYAN = "\u001b[46;1m"
    BG_BR_WHITE = "\u001b[47;1m"
    RESET = "\033[0;0m"
    BOLD = "\033[;1m"
    REVERSE = "\033[;7m"
    UNDERLINE = "\u001b[4m"
    __author__ = "Patan Musthakheem Khan"
    __version__ = 0.1
    __licence__ = "Apache 2.0"
